# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class UrlFieldErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class UrlFieldError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> UrlFieldErrorEnum.UrlFieldError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[UrlFieldErrorEnum.UrlFieldError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, UrlFieldErrorEnum.UrlFieldError]]: ...
        UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 0)
        UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 1)
        INVALID_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 2)
        INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 3)
        MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 4)
        MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 5)
        INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 6)
        MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 7)
        MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 8)
        INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 9)
        REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 10)
        INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 11)
        INVALID_TAG_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 12)
        REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 13)
        MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 14)
        INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 15)
        MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 16)
        MISSING_HOST_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 17)
        INVALID_TLD_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 18)
        INVALID_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 19)
        INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 20)
        REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 21)
        MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 22)
        INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 23)
        MALFORMED_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 24)
        MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 25)
        INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 26)
        INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 27)
        INVALID_TAG_IN_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 28)
        REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 29)
        MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 30)
        INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 31)
        INVALID_PROTOCOL_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 32)
        INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 33)
        URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(UrlFieldErrorEnum.UrlFieldError, 34)
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(UrlFieldErrorEnum.UrlFieldError, 39)
        INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 40)
        INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 41)
        REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 42)
        MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 43)
        INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 52)
        INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 44)
        DESTINATION_URL_DEPRECATED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 45)
        INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 46)
        MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 47)
        DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 48)
        INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 49)
        FINAL_URL_SUFFIX_MALFORMED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 50)
        INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(UrlFieldErrorEnum.UrlFieldError, 51)
        INVALID_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 53)
        MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 54)
        MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 55)
        MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldError, 56)
        NULL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 57)
    UNSPECIFIED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 0)
    UNKNOWN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 1)
    INVALID_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 2)
    INVALID_TAG_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 3)
    MISSING_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 4)
    MISSING_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 5)
    INVALID_PROTOCOL_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 6)
    MALFORMED_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 7)
    MISSING_HOST_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 8)
    INVALID_TLD_IN_TRACKING_URL_TEMPLATE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 9)
    REDUNDANT_NESTED_TRACKING_URL_TEMPLATE_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 10)
    INVALID_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 11)
    INVALID_TAG_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 12)
    REDUNDANT_NESTED_FINAL_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 13)
    MISSING_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 14)
    INVALID_PROTOCOL_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 15)
    MALFORMED_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 16)
    MISSING_HOST_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 17)
    INVALID_TLD_IN_FINAL_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 18)
    INVALID_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 19)
    INVALID_TAG_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 20)
    REDUNDANT_NESTED_FINAL_MOBILE_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 21)
    MISSING_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 22)
    INVALID_PROTOCOL_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 23)
    MALFORMED_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 24)
    MISSING_HOST_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 25)
    INVALID_TLD_IN_FINAL_MOBILE_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 26)
    INVALID_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 27)
    INVALID_TAG_IN_FINAL_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 28)
    REDUNDANT_NESTED_FINAL_APP_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 29)
    MULTIPLE_APP_URLS_FOR_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 30)
    INVALID_OSTYPE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 31)
    INVALID_PROTOCOL_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 32)
    INVALID_PACKAGE_ID_FOR_APP_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 33)
    URL_CUSTOM_PARAMETERS_COUNT_EXCEEDS_LIMIT = typing___cast(UrlFieldErrorEnum.UrlFieldError, 34)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_KEY = typing___cast(UrlFieldErrorEnum.UrlFieldError, 39)
    INVALID_CHARACTERS_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 40)
    INVALID_TAG_IN_URL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 41)
    REDUNDANT_NESTED_URL_CUSTOM_PARAMETER_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 42)
    MISSING_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 43)
    INVALID_PROTOCOL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 52)
    INVALID_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 44)
    DESTINATION_URL_DEPRECATED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 45)
    INVALID_TAG_IN_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 46)
    MISSING_URL_TAG = typing___cast(UrlFieldErrorEnum.UrlFieldError, 47)
    DUPLICATE_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 48)
    INVALID_URL_ID = typing___cast(UrlFieldErrorEnum.UrlFieldError, 49)
    FINAL_URL_SUFFIX_MALFORMED = typing___cast(UrlFieldErrorEnum.UrlFieldError, 50)
    INVALID_TAG_IN_FINAL_URL_SUFFIX = typing___cast(UrlFieldErrorEnum.UrlFieldError, 51)
    INVALID_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 53)
    MALFORMED_TOP_LEVEL_DOMAIN = typing___cast(UrlFieldErrorEnum.UrlFieldError, 54)
    MALFORMED_URL = typing___cast(UrlFieldErrorEnum.UrlFieldError, 55)
    MISSING_HOST = typing___cast(UrlFieldErrorEnum.UrlFieldError, 56)
    NULL_CUSTOM_PARAMETER_VALUE = typing___cast(UrlFieldErrorEnum.UrlFieldError, 57)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UrlFieldErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ExternalConversionSourceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ExternalConversionSource(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ExternalConversionSourceEnum.ExternalConversionSource: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ExternalConversionSourceEnum.ExternalConversionSource]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ExternalConversionSourceEnum.ExternalConversionSource]]: ...
        UNSPECIFIED = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 0)
        UNKNOWN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 1)
        WEBPAGE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 2)
        ANALYTICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 3)
        UPLOAD = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 4)
        AD_CALL_METRICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 5)
        WEBSITE_CALL_METRICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 6)
        STORE_VISITS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 7)
        ANDROID_IN_APP = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 8)
        IOS_IN_APP = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 9)
        IOS_FIRST_OPEN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 10)
        APP_UNSPECIFIED = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 11)
        ANDROID_FIRST_OPEN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 12)
        UPLOAD_CALLS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 13)
        FIREBASE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 14)
        CLICK_TO_CALL = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 15)
        SALESFORCE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 16)
        STORE_SALES_CRM = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 17)
        STORE_SALES_PAYMENT_NETWORK = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 18)
        GOOGLE_PLAY = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 19)
        THIRD_PARTY_APP_ANALYTICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 20)
        GOOGLE_ATTRIBUTION = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 21)
        STORE_SALES_DIRECT = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 22)
    UNSPECIFIED = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 0)
    UNKNOWN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 1)
    WEBPAGE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 2)
    ANALYTICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 3)
    UPLOAD = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 4)
    AD_CALL_METRICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 5)
    WEBSITE_CALL_METRICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 6)
    STORE_VISITS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 7)
    ANDROID_IN_APP = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 8)
    IOS_IN_APP = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 9)
    IOS_FIRST_OPEN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 10)
    APP_UNSPECIFIED = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 11)
    ANDROID_FIRST_OPEN = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 12)
    UPLOAD_CALLS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 13)
    FIREBASE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 14)
    CLICK_TO_CALL = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 15)
    SALESFORCE = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 16)
    STORE_SALES_CRM = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 17)
    STORE_SALES_PAYMENT_NETWORK = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 18)
    GOOGLE_PLAY = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 19)
    THIRD_PARTY_APP_ANALYTICS = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 20)
    GOOGLE_ATTRIBUTION = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 21)
    STORE_SALES_DIRECT = typing___cast(ExternalConversionSourceEnum.ExternalConversionSource, 22)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ExternalConversionSourceEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



from types import ModuleType
from google.ads.google_ads.v1.services import account_budget_proposal_service_client, account_budget_service_client, ad_group_ad_label_service_client, ad_group_ad_service_client, ad_group_audience_view_service_client, ad_group_bid_modifier_service_client, ad_group_criterion_label_service_client, ad_group_criterion_service_client, ad_group_criterion_simulation_service_client, ad_group_extension_setting_service_client, ad_group_feed_service_client, ad_group_label_service_client, ad_group_service_client, ad_group_simulation_service_client, ad_parameter_service_client, ad_schedule_view_service_client, age_range_view_service_client, asset_service_client, bidding_strategy_service_client, billing_setup_service_client, campaign_audience_view_service_client, campaign_bid_modifier_service_client, campaign_budget_service_client, campaign_criterion_service_client, campaign_criterion_simulation_service_client, campaign_draft_service_client, campaign_experiment_service_client, campaign_extension_setting_service_client, campaign_feed_service_client, campaign_label_service_client, campaign_service_client, campaign_shared_set_service_client, carrier_constant_service_client, change_status_service_client, click_view_service_client, conversion_action_service_client, conversion_adjustment_upload_service_client, conversion_upload_service_client, custom_interest_service_client, customer_client_link_service_client, customer_client_service_client, customer_extension_setting_service_client, customer_feed_service_client, customer_label_service_client, customer_manager_link_service_client, customer_negative_criterion_service_client, customer_service_client, detail_placement_view_service_client, display_keyword_view_service_client, domain_category_service_client, dynamic_search_ads_search_term_view_service_client, enums as enums, expanded_landing_page_view_service_client, extension_feed_item_service_client, feed_item_service_client, feed_item_target_service_client, feed_mapping_service_client, feed_placeholder_view_service_client, feed_service_client, gender_view_service_client, geo_target_constant_service_client, geographic_view_service_client, google_ads_field_service_client, google_ads_service_client, group_placement_view_service_client, hotel_group_view_service_client, hotel_performance_view_service_client, keyword_plan_ad_group_service_client, keyword_plan_campaign_service_client, keyword_plan_idea_service_client, keyword_plan_keyword_service_client, keyword_plan_negative_keyword_service_client, keyword_plan_service_client, keyword_view_service_client, label_service_client, landing_page_view_service_client, language_constant_service_client, location_view_service_client, managed_placement_view_service_client, media_file_service_client, merchant_center_link_service_client, mobile_app_category_constant_service_client, mobile_device_constant_service_client, mutate_job_service_client, operating_system_version_constant_service_client, paid_organic_search_term_view_service_client, parental_status_view_service_client, payments_account_service_client, product_bidding_category_constant_service_client, product_group_view_service_client, recommendation_service_client, remarketing_action_service_client, search_term_view_service_client, shared_criterion_service_client, shared_set_service_client, shopping_performance_view_service_client, topic_constant_service_client, topic_view_service_client, user_interest_service_client, user_list_service_client, video_service_client
from google.ads.google_ads.v1.services.transports import account_budget_proposal_service_grpc_transport, account_budget_service_grpc_transport, ad_group_ad_label_service_grpc_transport, ad_group_ad_service_grpc_transport, ad_group_audience_view_service_grpc_transport, ad_group_bid_modifier_service_grpc_transport, ad_group_criterion_label_service_grpc_transport, ad_group_criterion_service_grpc_transport, ad_group_criterion_simulation_service_grpc_transport, ad_group_extension_setting_service_grpc_transport, ad_group_feed_service_grpc_transport, ad_group_label_service_grpc_transport, ad_group_service_grpc_transport, ad_group_simulation_service_grpc_transport, ad_parameter_service_grpc_transport, ad_schedule_view_service_grpc_transport, age_range_view_service_grpc_transport, asset_service_grpc_transport, bidding_strategy_service_grpc_transport, billing_setup_service_grpc_transport, campaign_audience_view_service_grpc_transport, campaign_bid_modifier_service_grpc_transport, campaign_budget_service_grpc_transport, campaign_criterion_service_grpc_transport, campaign_criterion_simulation_service_grpc_transport, campaign_draft_service_grpc_transport, campaign_experiment_service_grpc_transport, campaign_extension_setting_service_grpc_transport, campaign_feed_service_grpc_transport, campaign_label_service_grpc_transport, campaign_service_grpc_transport, campaign_shared_set_service_grpc_transport, carrier_constant_service_grpc_transport, change_status_service_grpc_transport, click_view_service_grpc_transport, conversion_action_service_grpc_transport, conversion_adjustment_upload_service_grpc_transport, conversion_upload_service_grpc_transport, custom_interest_service_grpc_transport, customer_client_link_service_grpc_transport, customer_client_service_grpc_transport, customer_extension_setting_service_grpc_transport, customer_feed_service_grpc_transport, customer_label_service_grpc_transport, customer_manager_link_service_grpc_transport, customer_negative_criterion_service_grpc_transport, customer_service_grpc_transport, detail_placement_view_service_grpc_transport, display_keyword_view_service_grpc_transport, domain_category_service_grpc_transport, dynamic_search_ads_search_term_view_service_grpc_transport, expanded_landing_page_view_service_grpc_transport, extension_feed_item_service_grpc_transport, feed_item_service_grpc_transport, feed_item_target_service_grpc_transport, feed_mapping_service_grpc_transport, feed_placeholder_view_service_grpc_transport, feed_service_grpc_transport, gender_view_service_grpc_transport, geo_target_constant_service_grpc_transport, geographic_view_service_grpc_transport, google_ads_field_service_grpc_transport, google_ads_service_grpc_transport, group_placement_view_service_grpc_transport, hotel_group_view_service_grpc_transport, hotel_performance_view_service_grpc_transport, keyword_plan_ad_group_service_grpc_transport, keyword_plan_campaign_service_grpc_transport, keyword_plan_idea_service_grpc_transport, keyword_plan_keyword_service_grpc_transport, keyword_plan_negative_keyword_service_grpc_transport, keyword_plan_service_grpc_transport, keyword_view_service_grpc_transport, label_service_grpc_transport, landing_page_view_service_grpc_transport, language_constant_service_grpc_transport, location_view_service_grpc_transport, managed_placement_view_service_grpc_transport, media_file_service_grpc_transport, merchant_center_link_service_grpc_transport, mobile_app_category_constant_service_grpc_transport, mobile_device_constant_service_grpc_transport, mutate_job_service_grpc_transport, operating_system_version_constant_service_grpc_transport, paid_organic_search_term_view_service_grpc_transport, parental_status_view_service_grpc_transport, payments_account_service_grpc_transport, product_bidding_category_constant_service_grpc_transport, product_group_view_service_grpc_transport, recommendation_service_grpc_transport, remarketing_action_service_grpc_transport, search_term_view_service_grpc_transport, shared_criterion_service_grpc_transport, shared_set_service_grpc_transport, shopping_performance_view_service_grpc_transport, topic_constant_service_grpc_transport, topic_view_service_grpc_transport, user_interest_service_grpc_transport, user_list_service_grpc_transport, video_service_grpc_transport

class AccountBudgetProposalServiceClient(account_budget_proposal_service_client.AccountBudgetProposalServiceClient):
    enums: ModuleType = ...

class AccountBudgetServiceClient(account_budget_service_client.AccountBudgetServiceClient):
    enums: ModuleType = ...

class AdGroupAdLabelServiceClient(ad_group_ad_label_service_client.AdGroupAdLabelServiceClient):
    enums: ModuleType = ...

class AdGroupAdServiceClient(ad_group_ad_service_client.AdGroupAdServiceClient):
    enums: ModuleType = ...

class AdGroupAudienceViewServiceClient(ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient):
    enums: ModuleType = ...

class AdGroupBidModifierServiceClient(ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient):
    enums: ModuleType = ...

class AdGroupCriterionLabelServiceClient(ad_group_criterion_label_service_client.AdGroupCriterionLabelServiceClient):
    enums: ModuleType = ...

class AdGroupCriterionServiceClient(ad_group_criterion_service_client.AdGroupCriterionServiceClient):
    enums: ModuleType = ...

class AdGroupCriterionSimulationServiceClient(ad_group_criterion_simulation_service_client.AdGroupCriterionSimulationServiceClient):
    enums: ModuleType = ...

class AdGroupExtensionSettingServiceClient(ad_group_extension_setting_service_client.AdGroupExtensionSettingServiceClient):
    enums: ModuleType = ...

class AdGroupFeedServiceClient(ad_group_feed_service_client.AdGroupFeedServiceClient):
    enums: ModuleType = ...

class AdGroupLabelServiceClient(ad_group_label_service_client.AdGroupLabelServiceClient):
    enums: ModuleType = ...

class AdGroupServiceClient(ad_group_service_client.AdGroupServiceClient):
    enums: ModuleType = ...

class AdGroupSimulationServiceClient(ad_group_simulation_service_client.AdGroupSimulationServiceClient):
    enums: ModuleType = ...

class AdParameterServiceClient(ad_parameter_service_client.AdParameterServiceClient):
    enums: ModuleType = ...

class AdScheduleViewServiceClient(ad_schedule_view_service_client.AdScheduleViewServiceClient):
    enums: ModuleType = ...

class AgeRangeViewServiceClient(age_range_view_service_client.AgeRangeViewServiceClient):
    enums: ModuleType = ...

class AssetServiceClient(asset_service_client.AssetServiceClient):
    enums: ModuleType = ...

class BiddingStrategyServiceClient(bidding_strategy_service_client.BiddingStrategyServiceClient):
    enums: ModuleType = ...

class BillingSetupServiceClient(billing_setup_service_client.BillingSetupServiceClient):
    enums: ModuleType = ...

class CampaignAudienceViewServiceClient(campaign_audience_view_service_client.CampaignAudienceViewServiceClient):
    enums: ModuleType = ...

class CampaignBidModifierServiceClient(campaign_bid_modifier_service_client.CampaignBidModifierServiceClient):
    enums: ModuleType = ...

class CampaignBudgetServiceClient(campaign_budget_service_client.CampaignBudgetServiceClient):
    enums: ModuleType = ...

class CampaignCriterionServiceClient(campaign_criterion_service_client.CampaignCriterionServiceClient):
    enums: ModuleType = ...

class CampaignCriterionSimulationServiceClient(campaign_criterion_simulation_service_client.CampaignCriterionSimulationServiceClient):
    enums: ModuleType = ...

class CampaignDraftServiceClient(campaign_draft_service_client.CampaignDraftServiceClient):
    enums: ModuleType = ...

class CampaignExperimentServiceClient(campaign_experiment_service_client.CampaignExperimentServiceClient):
    enums: ModuleType = ...

class CampaignExtensionSettingServiceClient(campaign_extension_setting_service_client.CampaignExtensionSettingServiceClient):
    enums: ModuleType = ...

class CampaignFeedServiceClient(campaign_feed_service_client.CampaignFeedServiceClient):
    enums: ModuleType = ...

class CampaignLabelServiceClient(campaign_label_service_client.CampaignLabelServiceClient):
    enums: ModuleType = ...

class CampaignServiceClient(campaign_service_client.CampaignServiceClient):
    enums: ModuleType = ...

class CampaignSharedSetServiceClient(campaign_shared_set_service_client.CampaignSharedSetServiceClient):
    enums: ModuleType = ...

class CarrierConstantServiceClient(carrier_constant_service_client.CarrierConstantServiceClient):
    enums: ModuleType = ...

class ChangeStatusServiceClient(change_status_service_client.ChangeStatusServiceClient):
    enums: ModuleType = ...

class ClickViewServiceClient(click_view_service_client.ClickViewServiceClient):
    enums: ModuleType = ...

class ConversionActionServiceClient(conversion_action_service_client.ConversionActionServiceClient):
    enums: ModuleType = ...

class ConversionAdjustmentUploadServiceClient(conversion_adjustment_upload_service_client.ConversionAdjustmentUploadServiceClient):
    enums: ModuleType = ...

class ConversionUploadServiceClient(conversion_upload_service_client.ConversionUploadServiceClient):
    enums: ModuleType = ...

class CustomerClientLinkServiceClient(customer_client_link_service_client.CustomerClientLinkServiceClient):
    enums: ModuleType = ...

class CustomerClientServiceClient(customer_client_service_client.CustomerClientServiceClient):
    enums: ModuleType = ...

class CustomerExtensionSettingServiceClient(customer_extension_setting_service_client.CustomerExtensionSettingServiceClient):
    enums: ModuleType = ...

class CustomerFeedServiceClient(customer_feed_service_client.CustomerFeedServiceClient):
    enums: ModuleType = ...

class CustomerLabelServiceClient(customer_label_service_client.CustomerLabelServiceClient):
    enums: ModuleType = ...

class CustomerManagerLinkServiceClient(customer_manager_link_service_client.CustomerManagerLinkServiceClient):
    enums: ModuleType = ...

class CustomerNegativeCriterionServiceClient(customer_negative_criterion_service_client.CustomerNegativeCriterionServiceClient):
    enums: ModuleType = ...

class CustomerServiceClient(customer_service_client.CustomerServiceClient):
    enums: ModuleType = ...

class CustomInterestServiceClient(custom_interest_service_client.CustomInterestServiceClient):
    enums: ModuleType = ...

class DetailPlacementViewServiceClient(detail_placement_view_service_client.DetailPlacementViewServiceClient):
    enums: ModuleType = ...

class DisplayKeywordViewServiceClient(display_keyword_view_service_client.DisplayKeywordViewServiceClient):
    enums: ModuleType = ...

class DomainCategoryServiceClient(domain_category_service_client.DomainCategoryServiceClient):
    enums: ModuleType = ...

class DynamicSearchAdsSearchTermViewServiceClient(dynamic_search_ads_search_term_view_service_client.DynamicSearchAdsSearchTermViewServiceClient):
    enums: ModuleType = ...

class ExpandedLandingPageViewServiceClient(expanded_landing_page_view_service_client.ExpandedLandingPageViewServiceClient):
    enums: ModuleType = ...

class ExtensionFeedItemServiceClient(extension_feed_item_service_client.ExtensionFeedItemServiceClient):
    enums: ModuleType = ...

class FeedItemServiceClient(feed_item_service_client.FeedItemServiceClient):
    enums: ModuleType = ...

class FeedItemTargetServiceClient(feed_item_target_service_client.FeedItemTargetServiceClient):
    enums: ModuleType = ...

class FeedMappingServiceClient(feed_mapping_service_client.FeedMappingServiceClient):
    enums: ModuleType = ...

class FeedPlaceholderViewServiceClient(feed_placeholder_view_service_client.FeedPlaceholderViewServiceClient):
    enums: ModuleType = ...

class FeedServiceClient(feed_service_client.FeedServiceClient):
    enums: ModuleType = ...

class GenderViewServiceClient(gender_view_service_client.GenderViewServiceClient):
    enums: ModuleType = ...

class GeographicViewServiceClient(geographic_view_service_client.GeographicViewServiceClient):
    enums: ModuleType = ...

class GeoTargetConstantServiceClient(geo_target_constant_service_client.GeoTargetConstantServiceClient):
    enums: ModuleType = ...

class GoogleAdsFieldServiceClient(google_ads_field_service_client.GoogleAdsFieldServiceClient):
    enums: ModuleType = ...

class GoogleAdsServiceClient(google_ads_service_client.GoogleAdsServiceClient):
    enums: ModuleType = ...

class GroupPlacementViewServiceClient(group_placement_view_service_client.GroupPlacementViewServiceClient):
    enums: ModuleType = ...

class HotelGroupViewServiceClient(hotel_group_view_service_client.HotelGroupViewServiceClient):
    enums: ModuleType = ...

class HotelPerformanceViewServiceClient(hotel_performance_view_service_client.HotelPerformanceViewServiceClient):
    enums: ModuleType = ...

class KeywordPlanAdGroupServiceClient(keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient):
    enums: ModuleType = ...

class KeywordPlanCampaignServiceClient(keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient):
    enums: ModuleType = ...

class KeywordPlanIdeaServiceClient(keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient):
    enums: ModuleType = ...

class KeywordPlanKeywordServiceClient(keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient):
    enums: ModuleType = ...

class KeywordPlanNegativeKeywordServiceClient(keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient):
    enums: ModuleType = ...

class KeywordPlanServiceClient(keyword_plan_service_client.KeywordPlanServiceClient):
    enums: ModuleType = ...

class KeywordViewServiceClient(keyword_view_service_client.KeywordViewServiceClient):
    enums: ModuleType = ...

class LabelServiceClient(label_service_client.LabelServiceClient):
    enums: ModuleType = ...

class LandingPageViewServiceClient(landing_page_view_service_client.LandingPageViewServiceClient):
    enums: ModuleType = ...

class LanguageConstantServiceClient(language_constant_service_client.LanguageConstantServiceClient):
    enums: ModuleType = ...

class LocationViewServiceClient(location_view_service_client.LocationViewServiceClient):
    enums: ModuleType = ...

class ManagedPlacementViewServiceClient(managed_placement_view_service_client.ManagedPlacementViewServiceClient):
    enums: ModuleType = ...

class MediaFileServiceClient(media_file_service_client.MediaFileServiceClient):
    enums: ModuleType = ...

class MerchantCenterLinkServiceClient(merchant_center_link_service_client.MerchantCenterLinkServiceClient):
    enums: ModuleType = ...

class MobileAppCategoryConstantServiceClient(mobile_app_category_constant_service_client.MobileAppCategoryConstantServiceClient):
    enums: ModuleType = ...

class MobileDeviceConstantServiceClient(mobile_device_constant_service_client.MobileDeviceConstantServiceClient):
    enums: ModuleType = ...

class MutateJobServiceClient(mutate_job_service_client.MutateJobServiceClient):
    enums: ModuleType = ...

class OperatingSystemVersionConstantServiceClient(operating_system_version_constant_service_client.OperatingSystemVersionConstantServiceClient):
    enums: ModuleType = ...

class PaidOrganicSearchTermViewServiceClient(paid_organic_search_term_view_service_client.PaidOrganicSearchTermViewServiceClient):
    enums: ModuleType = ...

class ParentalStatusViewServiceClient(parental_status_view_service_client.ParentalStatusViewServiceClient):
    enums: ModuleType = ...

class PaymentsAccountServiceClient(payments_account_service_client.PaymentsAccountServiceClient):
    enums: ModuleType = ...

class ProductBiddingCategoryConstantServiceClient(product_bidding_category_constant_service_client.ProductBiddingCategoryConstantServiceClient):
    enums: ModuleType = ...

class ProductGroupViewServiceClient(product_group_view_service_client.ProductGroupViewServiceClient):
    enums: ModuleType = ...

class RecommendationServiceClient(recommendation_service_client.RecommendationServiceClient):
    enums: ModuleType = ...

class RemarketingActionServiceClient(remarketing_action_service_client.RemarketingActionServiceClient):
    enums: ModuleType = ...

class SearchTermViewServiceClient(search_term_view_service_client.SearchTermViewServiceClient):
    enums: ModuleType = ...

class SharedCriterionServiceClient(shared_criterion_service_client.SharedCriterionServiceClient):
    enums: ModuleType = ...

class SharedSetServiceClient(shared_set_service_client.SharedSetServiceClient):
    enums: ModuleType = ...

class ShoppingPerformanceViewServiceClient(shopping_performance_view_service_client.ShoppingPerformanceViewServiceClient):
    enums: ModuleType = ...

class TopicConstantServiceClient(topic_constant_service_client.TopicConstantServiceClient):
    enums: ModuleType = ...

class TopicViewServiceClient(topic_view_service_client.TopicViewServiceClient):
    enums: ModuleType = ...

class UserInterestServiceClient(user_interest_service_client.UserInterestServiceClient):
    enums: ModuleType = ...

class UserListServiceClient(user_list_service_client.UserListServiceClient):
    enums: ModuleType = ...

class VideoServiceClient(video_service_client.VideoServiceClient):
    enums: ModuleType = ...

class AccountBudgetProposalServiceGrpcTransport(account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport):
    ...

class AccountBudgetServiceGrpcTransport(account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport):
    ...

class AdGroupAdLabelServiceGrpcTransport(ad_group_ad_label_service_grpc_transport.AdGroupAdLabelServiceGrpcTransport):
    ...

class AdGroupAdServiceGrpcTransport(ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport):
    ...

class AdGroupAudienceViewServiceGrpcTransport(ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport):
    ...

class AdGroupBidModifierServiceGrpcTransport(ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport):
    ...

class AdGroupCriterionLabelServiceGrpcTransport(ad_group_criterion_label_service_grpc_transport.AdGroupCriterionLabelServiceGrpcTransport):
    ...

class AdGroupCriterionServiceGrpcTransport(ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport):
    ...

class AdGroupCriterionSimulationServiceGrpcTransport(ad_group_criterion_simulation_service_grpc_transport.AdGroupCriterionSimulationServiceGrpcTransport):
    ...

class AdGroupExtensionSettingServiceGrpcTransport(ad_group_extension_setting_service_grpc_transport.AdGroupExtensionSettingServiceGrpcTransport):
    ...

class AdGroupFeedServiceGrpcTransport(ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport):
    ...

class AdGroupLabelServiceGrpcTransport(ad_group_label_service_grpc_transport.AdGroupLabelServiceGrpcTransport):
    ...

class AdGroupServiceGrpcTransport(ad_group_service_grpc_transport.AdGroupServiceGrpcTransport):
    ...

class AdGroupSimulationServiceGrpcTransport(ad_group_simulation_service_grpc_transport.AdGroupSimulationServiceGrpcTransport):
    ...

class AdParameterServiceGrpcTransport(ad_parameter_service_grpc_transport.AdParameterServiceGrpcTransport):
    ...

class AdScheduleViewServiceGrpcTransport(ad_schedule_view_service_grpc_transport.AdScheduleViewServiceGrpcTransport):
    ...

class AgeRangeViewServiceGrpcTransport(age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport):
    ...

class AssetServiceGrpcTransport(asset_service_grpc_transport.AssetServiceGrpcTransport):
    ...

class BiddingStrategyServiceGrpcTransport(bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport):
    ...

class BillingSetupServiceGrpcTransport(billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport):
    ...

class CampaignAudienceViewServiceGrpcTransport(campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport):
    ...

class CampaignBidModifierServiceGrpcTransport(campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport):
    ...

class CampaignBudgetServiceGrpcTransport(campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport):
    ...

class CampaignCriterionServiceGrpcTransport(campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport):
    ...

class CampaignCriterionSimulationServiceGrpcTransport(campaign_criterion_simulation_service_grpc_transport.CampaignCriterionSimulationServiceGrpcTransport):
    ...

class CampaignDraftServiceGrpcTransport(campaign_draft_service_grpc_transport.CampaignDraftServiceGrpcTransport):
    ...

class CampaignExperimentServiceGrpcTransport(campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport):
    ...

class CampaignExtensionSettingServiceGrpcTransport(campaign_extension_setting_service_grpc_transport.CampaignExtensionSettingServiceGrpcTransport):
    ...

class CampaignFeedServiceGrpcTransport(campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport):
    ...

class CampaignLabelServiceGrpcTransport(campaign_label_service_grpc_transport.CampaignLabelServiceGrpcTransport):
    ...

class CampaignServiceGrpcTransport(campaign_service_grpc_transport.CampaignServiceGrpcTransport):
    ...

class CampaignSharedSetServiceGrpcTransport(campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport):
    ...

class CarrierConstantServiceGrpcTransport(carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport):
    ...

class ChangeStatusServiceGrpcTransport(change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport):
    ...

class ClickViewServiceGrpcTransport(click_view_service_grpc_transport.ClickViewServiceGrpcTransport):
    ...

class ConversionActionServiceGrpcTransport(conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport):
    ...

class ConversionAdjustmentUploadServiceGrpcTransport(conversion_adjustment_upload_service_grpc_transport.ConversionAdjustmentUploadServiceGrpcTransport):
    ...

class ConversionUploadServiceGrpcTransport(conversion_upload_service_grpc_transport.ConversionUploadServiceGrpcTransport):
    ...

class CustomerClientLinkServiceGrpcTransport(customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport):
    ...

class CustomerClientServiceGrpcTransport(customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport):
    ...

class CustomerExtensionSettingServiceGrpcTransport(customer_extension_setting_service_grpc_transport.CustomerExtensionSettingServiceGrpcTransport):
    ...

class CustomerFeedServiceGrpcTransport(customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport):
    ...

class CustomerLabelServiceGrpcTransport(customer_label_service_grpc_transport.CustomerLabelServiceGrpcTransport):
    ...

class CustomerManagerLinkServiceGrpcTransport(customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport):
    ...

class CustomerNegativeCriterionServiceGrpcTransport(customer_negative_criterion_service_grpc_transport.CustomerNegativeCriterionServiceGrpcTransport):
    ...

class CustomerServiceGrpcTransport(customer_service_grpc_transport.CustomerServiceGrpcTransport):
    ...

class CustomInterestServiceGrpcTransport(custom_interest_service_grpc_transport.CustomInterestServiceGrpcTransport):
    ...

class DetailPlacementViewServiceGrpcTransport(detail_placement_view_service_grpc_transport.DetailPlacementViewServiceGrpcTransport):
    ...

class DisplayKeywordViewServiceGrpcTransport(display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport):
    ...

class DomainCategoryServiceGrpcTransport(domain_category_service_grpc_transport.DomainCategoryServiceGrpcTransport):
    ...

class DynamicSearchAdsSearchTermViewServiceGrpcTransport(dynamic_search_ads_search_term_view_service_grpc_transport.DynamicSearchAdsSearchTermViewServiceGrpcTransport):
    ...

class ExpandedLandingPageViewServiceGrpcTransport(expanded_landing_page_view_service_grpc_transport.ExpandedLandingPageViewServiceGrpcTransport):
    ...

class ExtensionFeedItemServiceGrpcTransport(extension_feed_item_service_grpc_transport.ExtensionFeedItemServiceGrpcTransport):
    ...

class FeedItemServiceGrpcTransport(feed_item_service_grpc_transport.FeedItemServiceGrpcTransport):
    ...

class FeedItemTargetServiceGrpcTransport(feed_item_target_service_grpc_transport.FeedItemTargetServiceGrpcTransport):
    ...

class FeedMappingServiceGrpcTransport(feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport):
    ...

class FeedPlaceholderViewServiceGrpcTransport(feed_placeholder_view_service_grpc_transport.FeedPlaceholderViewServiceGrpcTransport):
    ...

class FeedServiceGrpcTransport(feed_service_grpc_transport.FeedServiceGrpcTransport):
    ...

class GenderViewServiceGrpcTransport(gender_view_service_grpc_transport.GenderViewServiceGrpcTransport):
    ...

class GeographicViewServiceGrpcTransport(geographic_view_service_grpc_transport.GeographicViewServiceGrpcTransport):
    ...

class GeoTargetConstantServiceGrpcTransport(geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport):
    ...

class GoogleAdsFieldServiceGrpcTransport(google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport):
    ...

class GoogleAdsServiceGrpcTransport(google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport):
    ...

class GroupPlacementViewServiceGrpcTransport(group_placement_view_service_grpc_transport.GroupPlacementViewServiceGrpcTransport):
    ...

class HotelGroupViewServiceGrpcTransport(hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport):
    ...

class HotelPerformanceViewServiceGrpcTransport(hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport):
    ...

class KeywordPlanAdGroupServiceGrpcTransport(keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport):
    ...

class KeywordPlanCampaignServiceGrpcTransport(keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport):
    ...

class KeywordPlanIdeaServiceGrpcTransport(keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport):
    ...

class KeywordPlanKeywordServiceGrpcTransport(keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport):
    ...

class KeywordPlanNegativeKeywordServiceGrpcTransport(keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport):
    ...

class KeywordPlanServiceGrpcTransport(keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport):
    ...

class KeywordViewServiceGrpcTransport(keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport):
    ...

class LabelServiceGrpcTransport(label_service_grpc_transport.LabelServiceGrpcTransport):
    ...

class LandingPageViewServiceGrpcTransport(landing_page_view_service_grpc_transport.LandingPageViewServiceGrpcTransport):
    ...

class LanguageConstantServiceGrpcTransport(language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport):
    ...

class LocationViewServiceGrpcTransport(location_view_service_grpc_transport.LocationViewServiceGrpcTransport):
    ...

class ManagedPlacementViewServiceGrpcTransport(managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport):
    ...

class MediaFileServiceGrpcTransport(media_file_service_grpc_transport.MediaFileServiceGrpcTransport):
    ...

class MerchantCenterLinkServiceGrpcTransport(merchant_center_link_service_grpc_transport.MerchantCenterLinkServiceGrpcTransport):
    ...

class MobileAppCategoryConstantServiceGrpcTransport(mobile_app_category_constant_service_grpc_transport.MobileAppCategoryConstantServiceGrpcTransport):
    ...

class MobileDeviceConstantServiceGrpcTransport(mobile_device_constant_service_grpc_transport.MobileDeviceConstantServiceGrpcTransport):
    ...

class MutateJobServiceGrpcTransport(mutate_job_service_grpc_transport.MutateJobServiceGrpcTransport):
    ...

class OperatingSystemVersionConstantServiceGrpcTransport(operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport):
    ...

class PaidOrganicSearchTermViewServiceGrpcTransport(paid_organic_search_term_view_service_grpc_transport.PaidOrganicSearchTermViewServiceGrpcTransport):
    ...

class ParentalStatusViewServiceGrpcTransport(parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport):
    ...

class PaymentsAccountServiceGrpcTransport(payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport):
    ...

class ProductBiddingCategoryConstantServiceGrpcTransport(product_bidding_category_constant_service_grpc_transport.ProductBiddingCategoryConstantServiceGrpcTransport):
    ...

class ProductGroupViewServiceGrpcTransport(product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport):
    ...

class RecommendationServiceGrpcTransport(recommendation_service_grpc_transport.RecommendationServiceGrpcTransport):
    ...

class RemarketingActionServiceGrpcTransport(remarketing_action_service_grpc_transport.RemarketingActionServiceGrpcTransport):
    ...

class SearchTermViewServiceGrpcTransport(search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport):
    ...

class SharedCriterionServiceGrpcTransport(shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport):
    ...

class SharedSetServiceGrpcTransport(shared_set_service_grpc_transport.SharedSetServiceGrpcTransport):
    ...

class ShoppingPerformanceViewServiceGrpcTransport(shopping_performance_view_service_grpc_transport.ShoppingPerformanceViewServiceGrpcTransport):
    ...

class TopicConstantServiceGrpcTransport(topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport):
    ...

class TopicViewServiceGrpcTransport(topic_view_service_grpc_transport.TopicViewServiceGrpcTransport):
    ...

class UserInterestServiceGrpcTransport(user_interest_service_grpc_transport.UserInterestServiceGrpcTransport):
    ...

class UserListServiceGrpcTransport(user_list_service_grpc_transport.UserListServiceGrpcTransport):
    ...

class VideoServiceGrpcTransport(video_service_grpc_transport.VideoServiceGrpcTransport):
    ...



import grpc  # type: ignore
from google.ads.google_ads.v1.services.transports.mutate_job_service_grpc_transport import MutateJobServiceGrpcTransport
from google.api_core.operation import Operation  # type: ignore
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Iterator
from google.ads.google_ads.v1.proto.resources.mutate_job_pb2 import MutateJob

from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import MutateOperation

from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import AddMutateJobOperationsResponse, \
    MutateJobResult, CreateMutateJobResponse


class MutateJobServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> MutateJobServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> MutateJobServiceClient: ...
    @classmethod
    def mutate_job_path(cls, customer: Any, mutate_job: Any) -> str: ...
    transport: Union[MutateJobServiceGrpcTransport, Callable[[Credentials, type], MutateJobServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[MutateJobServiceGrpcTransport, Callable[[Credentials, type], MutateJobServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def create_mutate_job(self, customer_id: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> CreateMutateJobResponse: ...
    def get_mutate_job(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> MutateJob: ...
    def list_mutate_job_results(self, resource_name: str, page_size: Optional[int] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Iterator[MutateJobResult]: ...
    def run_mutate_job(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Operation: ...
    def add_mutate_job_operations(self, resource_name: str, sequence_token: str, mutate_operations: List[Union[Dict[Any, Any], MutateOperation]], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> AddMutateJobOperationsResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.resources.payments_account_pb2 import (
    PaymentsAccount as google___ads___googleads___v2___resources___payments_account_pb2___PaymentsAccount,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class ListPaymentsAccountsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPaymentsAccountsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id"]) -> None: ...

class ListPaymentsAccountsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def payments_accounts(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___resources___payments_account_pb2___PaymentsAccount]: ...

    def __init__(self,
        *,
        payments_accounts : typing___Optional[typing___Iterable[google___ads___googleads___v2___resources___payments_account_pb2___PaymentsAccount]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListPaymentsAccountsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"payments_accounts"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"payments_accounts",b"payments_accounts"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.resources.customer_pb2 import (
    Customer as google___ads___googleads___v1___resources___customer_pb2___Customer,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)

from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetCustomerRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetCustomerRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateCustomerRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    validate_only = ... # type: bool

    @property
    def operation(self) -> CustomerOperation: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operation : typing___Optional[CustomerOperation] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operation",u"validate_only"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"operation",b"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operation",b"operation",u"validate_only",b"validate_only"]) -> None: ...

class CreateCustomerClientRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def customer_client(self) -> google___ads___googleads___v1___resources___customer_pb2___Customer: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        customer_client : typing___Optional[google___ads___googleads___v1___resources___customer_pb2___Customer] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateCustomerClientRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"customer_client"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_client",u"customer_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"customer_client",b"customer_client"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_client",b"customer_client",u"customer_id",b"customer_id"]) -> None: ...

class CustomerOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def update(self) -> google___ads___googleads___v1___resources___customer_pb2___Customer: ...

    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...

    def __init__(self,
        *,
        update : typing___Optional[google___ads___googleads___v1___resources___customer_pb2___Customer] = None,
        update_mask : typing___Optional[google___protobuf___field_mask_pb2___FieldMask] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomerOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"update",u"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"update",u"update_mask"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"update",b"update",u"update_mask",b"update_mask"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"update",b"update",u"update_mask",b"update_mask"]) -> None: ...

class CreateCustomerClientResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CreateCustomerClientResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateCustomerResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def result(self) -> MutateCustomerResult: ...

    def __init__(self,
        *,
        result : typing___Optional[MutateCustomerResult] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> None: ...

class MutateCustomerResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateCustomerResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class ListAccessibleCustomersRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListAccessibleCustomersRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class ListAccessibleCustomersResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_names = ... # type: google___protobuf___internal___containers___RepeatedScalarFieldContainer[typing___Text]

    def __init__(self,
        *,
        resource_names : typing___Optional[typing___Iterable[typing___Text]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListAccessibleCustomersResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_names"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_names",b"resource_names"]) -> None: ...



# Stubs for google.ads.google_ads.v2.proto.services.merchant_center_link_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class MerchantCenterLinkServiceStub:
    ListMerchantCenterLinks: Any = ...
    GetMerchantCenterLink: Any = ...
    MutateMerchantCenterLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MerchantCenterLinkServiceServicer:
    def ListMerchantCenterLinks(self, request: Any, context: Any) -> None: ...
    def GetMerchantCenterLink(self, request: Any, context: Any) -> None: ...
    def MutateMerchantCenterLink(self, request: Any, context: Any) -> None: ...

def add_MerchantCenterLinkServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    DeviceInfo as google___ads___googleads___v1___common___criteria_pb2___DeviceInfo,
    HotelAdvanceBookingWindowInfo as google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo,
    HotelCheckInDayInfo as google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo,
    HotelDateSelectionTypeInfo as google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo,
    HotelLengthOfStayInfo as google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo,
    PreferredContentInfo as google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo,
)

from google.ads.google_ads.v1.proto.enums.bid_modifier_source_pb2 import (
    BidModifierSourceEnum as google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupBidModifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    bid_modifier_source = ... # type: google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSource

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def base_ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def hotel_date_selection_type(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo: ...

    @property
    def hotel_advance_booking_window(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo: ...

    @property
    def hotel_length_of_stay(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo: ...

    @property
    def hotel_check_in_day(self) -> google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo: ...

    @property
    def device(self) -> google___ads___googleads___v1___common___criteria_pb2___DeviceInfo: ...

    @property
    def preferred_content(self) -> google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        criterion_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        bid_modifier : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        base_ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        bid_modifier_source : typing___Optional[google___ads___googleads___v1___enums___bid_modifier_source_pb2___BidModifierSourceEnum.BidModifierSource] = None,
        hotel_date_selection_type : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelDateSelectionTypeInfo] = None,
        hotel_advance_booking_window : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelAdvanceBookingWindowInfo] = None,
        hotel_length_of_stay : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelLengthOfStayInfo] = None,
        hotel_check_in_day : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___HotelCheckInDayInfo] = None,
        device : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___DeviceInfo] = None,
        preferred_content : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___PreferredContentInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupBidModifier: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"base_ad_group",u"bid_modifier",u"criterion",u"criterion_id",u"device",u"hotel_advance_booking_window",u"hotel_check_in_day",u"hotel_date_selection_type",u"hotel_length_of_stay",u"preferred_content"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"base_ad_group",u"bid_modifier",u"bid_modifier_source",u"criterion",u"criterion_id",u"device",u"hotel_advance_booking_window",u"hotel_check_in_day",u"hotel_date_selection_type",u"hotel_length_of_stay",u"preferred_content",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"base_ad_group",b"base_ad_group",u"bid_modifier",b"bid_modifier",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"hotel_advance_booking_window",b"hotel_advance_booking_window",u"hotel_check_in_day",b"hotel_check_in_day",u"hotel_date_selection_type",b"hotel_date_selection_type",u"hotel_length_of_stay",b"hotel_length_of_stay",u"preferred_content",b"preferred_content"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"base_ad_group",b"base_ad_group",u"bid_modifier",b"bid_modifier",u"bid_modifier_source",b"bid_modifier_source",u"criterion",b"criterion",u"criterion_id",b"criterion_id",u"device",b"device",u"hotel_advance_booking_window",b"hotel_advance_booking_window",u"hotel_check_in_day",b"hotel_check_in_day",u"hotel_date_selection_type",b"hotel_date_selection_type",u"hotel_length_of_stay",b"hotel_length_of_stay",u"preferred_content",b"preferred_content",u"resource_name",b"resource_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"criterion",b"criterion"]) -> typing_extensions___Literal["hotel_date_selection_type","hotel_advance_booking_window","hotel_length_of_stay","hotel_check_in_day","device","preferred_content"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ImageErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ImageError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ImageErrorEnum.ImageError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ImageErrorEnum.ImageError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ImageErrorEnum.ImageError]]: ...
        UNSPECIFIED = typing___cast(ImageErrorEnum.ImageError, 0)
        UNKNOWN = typing___cast(ImageErrorEnum.ImageError, 1)
        INVALID_IMAGE = typing___cast(ImageErrorEnum.ImageError, 2)
        STORAGE_ERROR = typing___cast(ImageErrorEnum.ImageError, 3)
        BAD_REQUEST = typing___cast(ImageErrorEnum.ImageError, 4)
        UNEXPECTED_SIZE = typing___cast(ImageErrorEnum.ImageError, 5)
        ANIMATED_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 6)
        ANIMATION_TOO_LONG = typing___cast(ImageErrorEnum.ImageError, 7)
        SERVER_ERROR = typing___cast(ImageErrorEnum.ImageError, 8)
        CMYK_JPEG_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 9)
        FLASH_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 10)
        FLASH_WITHOUT_CLICKTAG = typing___cast(ImageErrorEnum.ImageError, 11)
        FLASH_ERROR_AFTER_FIXING_CLICK_TAG = typing___cast(ImageErrorEnum.ImageError, 12)
        ANIMATED_VISUAL_EFFECT = typing___cast(ImageErrorEnum.ImageError, 13)
        FLASH_ERROR = typing___cast(ImageErrorEnum.ImageError, 14)
        LAYOUT_PROBLEM = typing___cast(ImageErrorEnum.ImageError, 15)
        PROBLEM_READING_IMAGE_FILE = typing___cast(ImageErrorEnum.ImageError, 16)
        ERROR_STORING_IMAGE = typing___cast(ImageErrorEnum.ImageError, 17)
        ASPECT_RATIO_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 18)
        FLASH_HAS_NETWORK_OBJECTS = typing___cast(ImageErrorEnum.ImageError, 19)
        FLASH_HAS_NETWORK_METHODS = typing___cast(ImageErrorEnum.ImageError, 20)
        FLASH_HAS_URL = typing___cast(ImageErrorEnum.ImageError, 21)
        FLASH_HAS_MOUSE_TRACKING = typing___cast(ImageErrorEnum.ImageError, 22)
        FLASH_HAS_RANDOM_NUM = typing___cast(ImageErrorEnum.ImageError, 23)
        FLASH_SELF_TARGETS = typing___cast(ImageErrorEnum.ImageError, 24)
        FLASH_BAD_GETURL_TARGET = typing___cast(ImageErrorEnum.ImageError, 25)
        FLASH_VERSION_NOT_SUPPORTED = typing___cast(ImageErrorEnum.ImageError, 26)
        FLASH_WITHOUT_HARD_CODED_CLICK_URL = typing___cast(ImageErrorEnum.ImageError, 27)
        INVALID_FLASH_FILE = typing___cast(ImageErrorEnum.ImageError, 28)
        FAILED_TO_FIX_CLICK_TAG_IN_FLASH = typing___cast(ImageErrorEnum.ImageError, 29)
        FLASH_ACCESSES_NETWORK_RESOURCES = typing___cast(ImageErrorEnum.ImageError, 30)
        FLASH_EXTERNAL_JS_CALL = typing___cast(ImageErrorEnum.ImageError, 31)
        FLASH_EXTERNAL_FS_CALL = typing___cast(ImageErrorEnum.ImageError, 32)
        FILE_TOO_LARGE = typing___cast(ImageErrorEnum.ImageError, 33)
        IMAGE_DATA_TOO_LARGE = typing___cast(ImageErrorEnum.ImageError, 34)
        IMAGE_PROCESSING_ERROR = typing___cast(ImageErrorEnum.ImageError, 35)
        IMAGE_TOO_SMALL = typing___cast(ImageErrorEnum.ImageError, 36)
        INVALID_INPUT = typing___cast(ImageErrorEnum.ImageError, 37)
        PROBLEM_READING_FILE = typing___cast(ImageErrorEnum.ImageError, 38)
    UNSPECIFIED = typing___cast(ImageErrorEnum.ImageError, 0)
    UNKNOWN = typing___cast(ImageErrorEnum.ImageError, 1)
    INVALID_IMAGE = typing___cast(ImageErrorEnum.ImageError, 2)
    STORAGE_ERROR = typing___cast(ImageErrorEnum.ImageError, 3)
    BAD_REQUEST = typing___cast(ImageErrorEnum.ImageError, 4)
    UNEXPECTED_SIZE = typing___cast(ImageErrorEnum.ImageError, 5)
    ANIMATED_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 6)
    ANIMATION_TOO_LONG = typing___cast(ImageErrorEnum.ImageError, 7)
    SERVER_ERROR = typing___cast(ImageErrorEnum.ImageError, 8)
    CMYK_JPEG_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 9)
    FLASH_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 10)
    FLASH_WITHOUT_CLICKTAG = typing___cast(ImageErrorEnum.ImageError, 11)
    FLASH_ERROR_AFTER_FIXING_CLICK_TAG = typing___cast(ImageErrorEnum.ImageError, 12)
    ANIMATED_VISUAL_EFFECT = typing___cast(ImageErrorEnum.ImageError, 13)
    FLASH_ERROR = typing___cast(ImageErrorEnum.ImageError, 14)
    LAYOUT_PROBLEM = typing___cast(ImageErrorEnum.ImageError, 15)
    PROBLEM_READING_IMAGE_FILE = typing___cast(ImageErrorEnum.ImageError, 16)
    ERROR_STORING_IMAGE = typing___cast(ImageErrorEnum.ImageError, 17)
    ASPECT_RATIO_NOT_ALLOWED = typing___cast(ImageErrorEnum.ImageError, 18)
    FLASH_HAS_NETWORK_OBJECTS = typing___cast(ImageErrorEnum.ImageError, 19)
    FLASH_HAS_NETWORK_METHODS = typing___cast(ImageErrorEnum.ImageError, 20)
    FLASH_HAS_URL = typing___cast(ImageErrorEnum.ImageError, 21)
    FLASH_HAS_MOUSE_TRACKING = typing___cast(ImageErrorEnum.ImageError, 22)
    FLASH_HAS_RANDOM_NUM = typing___cast(ImageErrorEnum.ImageError, 23)
    FLASH_SELF_TARGETS = typing___cast(ImageErrorEnum.ImageError, 24)
    FLASH_BAD_GETURL_TARGET = typing___cast(ImageErrorEnum.ImageError, 25)
    FLASH_VERSION_NOT_SUPPORTED = typing___cast(ImageErrorEnum.ImageError, 26)
    FLASH_WITHOUT_HARD_CODED_CLICK_URL = typing___cast(ImageErrorEnum.ImageError, 27)
    INVALID_FLASH_FILE = typing___cast(ImageErrorEnum.ImageError, 28)
    FAILED_TO_FIX_CLICK_TAG_IN_FLASH = typing___cast(ImageErrorEnum.ImageError, 29)
    FLASH_ACCESSES_NETWORK_RESOURCES = typing___cast(ImageErrorEnum.ImageError, 30)
    FLASH_EXTERNAL_JS_CALL = typing___cast(ImageErrorEnum.ImageError, 31)
    FLASH_EXTERNAL_FS_CALL = typing___cast(ImageErrorEnum.ImageError, 32)
    FILE_TOO_LARGE = typing___cast(ImageErrorEnum.ImageError, 33)
    IMAGE_DATA_TOO_LARGE = typing___cast(ImageErrorEnum.ImageError, 34)
    IMAGE_PROCESSING_ERROR = typing___cast(ImageErrorEnum.ImageError, 35)
    IMAGE_TOO_SMALL = typing___cast(ImageErrorEnum.ImageError, 36)
    INVALID_INPUT = typing___cast(ImageErrorEnum.ImageError, 37)
    PROBLEM_READING_FILE = typing___cast(ImageErrorEnum.ImageError, 38)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ImageErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v2___common___dates_pb2___DateRange,
)

from google.ads.google_ads.v2.proto.enums.invoice_type_pb2 import (
    InvoiceTypeEnum as google___ads___googleads___v2___enums___invoice_type_pb2___InvoiceTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Invoice(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AccountBudgetSummary(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def customer_descriptive_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def account_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def account_budget_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def purchase_order_number(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def subtotal_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def tax_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def total_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def billable_activity_date_range(self) -> google___ads___googleads___v2___common___dates_pb2___DateRange: ...

        def __init__(self,
            *,
            customer : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            customer_descriptive_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            account_budget : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            account_budget_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            purchase_order_number : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            subtotal_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            tax_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            total_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            billable_activity_date_range : typing___Optional[google___ads___googleads___v2___common___dates_pb2___DateRange] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Invoice.AccountBudgetSummary: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"account_budget",u"account_budget_name",u"billable_activity_date_range",u"customer",u"customer_descriptive_name",u"purchase_order_number",u"subtotal_amount_micros",u"tax_amount_micros",u"total_amount_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"account_budget",u"account_budget_name",u"billable_activity_date_range",u"customer",u"customer_descriptive_name",u"purchase_order_number",u"subtotal_amount_micros",u"tax_amount_micros",u"total_amount_micros"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"account_budget",b"account_budget",u"account_budget_name",b"account_budget_name",u"billable_activity_date_range",b"billable_activity_date_range",u"customer",b"customer",u"customer_descriptive_name",b"customer_descriptive_name",u"purchase_order_number",b"purchase_order_number",u"subtotal_amount_micros",b"subtotal_amount_micros",u"tax_amount_micros",b"tax_amount_micros",u"total_amount_micros",b"total_amount_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"account_budget",b"account_budget",u"account_budget_name",b"account_budget_name",u"billable_activity_date_range",b"billable_activity_date_range",u"customer",b"customer",u"customer_descriptive_name",b"customer_descriptive_name",u"purchase_order_number",b"purchase_order_number",u"subtotal_amount_micros",b"subtotal_amount_micros",u"tax_amount_micros",b"tax_amount_micros",u"total_amount_micros",b"total_amount_micros"]) -> None: ...

    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def billing_setup(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def payments_account_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def payments_profile_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def issue_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def due_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def service_date_range(self) -> google___ads___googleads___v2___common___dates_pb2___DateRange: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def invoice_level_adjustments_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def subtotal_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def tax_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def total_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def corrected_invoice(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def replaced_invoices(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def pdf_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def account_budget_summaries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[Invoice.AccountBudgetSummary]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceType] = None,
        billing_setup : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        payments_account_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        payments_profile_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        issue_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        due_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        service_date_range : typing___Optional[google___ads___googleads___v2___common___dates_pb2___DateRange] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        invoice_level_adjustments_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        subtotal_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        tax_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        total_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        corrected_invoice : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        replaced_invoices : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        pdf_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        account_budget_summaries : typing___Optional[typing___Iterable[Invoice.AccountBudgetSummary]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Invoice: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"billing_setup",u"corrected_invoice",u"currency_code",u"due_date",u"id",u"invoice_level_adjustments_micros",u"issue_date",u"payments_account_id",u"payments_profile_id",u"pdf_url",u"service_date_range",u"subtotal_amount_micros",u"tax_amount_micros",u"total_amount_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_summaries",u"billing_setup",u"corrected_invoice",u"currency_code",u"due_date",u"id",u"invoice_level_adjustments_micros",u"issue_date",u"payments_account_id",u"payments_profile_id",u"pdf_url",u"replaced_invoices",u"resource_name",u"service_date_range",u"subtotal_amount_micros",u"tax_amount_micros",u"total_amount_micros",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"billing_setup",b"billing_setup",u"corrected_invoice",b"corrected_invoice",u"currency_code",b"currency_code",u"due_date",b"due_date",u"id",b"id",u"invoice_level_adjustments_micros",b"invoice_level_adjustments_micros",u"issue_date",b"issue_date",u"payments_account_id",b"payments_account_id",u"payments_profile_id",b"payments_profile_id",u"pdf_url",b"pdf_url",u"service_date_range",b"service_date_range",u"subtotal_amount_micros",b"subtotal_amount_micros",u"tax_amount_micros",b"tax_amount_micros",u"total_amount_micros",b"total_amount_micros"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_budget_summaries",b"account_budget_summaries",u"billing_setup",b"billing_setup",u"corrected_invoice",b"corrected_invoice",u"currency_code",b"currency_code",u"due_date",b"due_date",u"id",b"id",u"invoice_level_adjustments_micros",b"invoice_level_adjustments_micros",u"issue_date",b"issue_date",u"payments_account_id",b"payments_account_id",u"payments_profile_id",b"payments_profile_id",u"pdf_url",b"pdf_url",u"replaced_invoices",b"replaced_invoices",u"resource_name",b"resource_name",u"service_date_range",b"service_date_range",u"subtotal_amount_micros",b"subtotal_amount_micros",u"tax_amount_micros",b"tax_amount_micros",u"total_amount_micros",b"total_amount_micros",u"type",b"type"]) -> None: ...
